
# Slot: predicate




URI: [biolink:pairwise_molecular_interaction_predicate](https://w3id.org/biolink/vocab/pairwise_molecular_interaction_predicate)


## Domain and Range

[PairwiseMolecularInteraction](PairwiseMolecularInteraction.md) &#8594;  <sub>1..1</sub> [PredicateType](types/PredicateType.md)

## Parents

 *  is_a: [pairwise gene to gene interaction➞predicate](pairwise_gene_to_gene_interaction_predicate.md)

## Children


## Used by

 * [PairwiseMolecularInteraction](PairwiseMolecularInteraction.md)
